import { AccountAddress, Chain, ChainAddress, Network, Ntt, NttTransceiver, ProtocolInitializer, TokenAddress, WormholeNttTransceiver } from '@wormhole-foundation/sdk-connect';
import type { EvmChains } from '@wormhole-foundation/sdk-evm';
import { EvmUnsignedTransaction } from '@wormhole-foundation/sdk-evm';
import '@wormhole-foundation/sdk-evm-core';
import type { Provider, TransactionRequest } from 'ethers';
import { ethers_contracts } from './index.js';
interface NttContracts {
    manager: string;
    transceiver: {
        wormhole?: string;
    };
}
export declare function evmNttProtocolFactory(token: string): ProtocolInitializer<'Evm', 'Ntt'>;
export declare class EvmNttWormholeTranceiver<N extends Network, C extends EvmChains> implements NttTransceiver<N, C, WormholeNttTransceiver.VAA> {
    readonly manager: EvmNtt<N, C>;
    readonly address: string;
    transceiver: ethers_contracts.WormholeTransceiver;
    constructor(manager: EvmNtt<N, C>, address: string);
    encodeFlags(skipRelay: boolean): Uint8Array;
    receive(attestation: WormholeNttTransceiver.VAA): AsyncGenerator<EvmUnsignedTransaction<N, C>, void, unknown>;
    isWormholeRelayingEnabled(destChain: Chain): Promise<boolean>;
    isSpecialRelayingEnabled(destChain: Chain): Promise<boolean>;
}
export declare abstract class EvmNtt<N extends Network, C extends EvmChains> implements Ntt<N, C> {
    readonly network: N;
    readonly chain: C;
    readonly provider: Provider;
    readonly contracts: NttContracts;
    abstract tokenAddress: string;
    readonly chainId: bigint;
    manager: ethers_contracts.NttManager;
    xcvrs: EvmNttWormholeTranceiver<N, C>[];
    managerAddress: string;
    constructor(network: N, chain: C, provider: Provider, contracts: NttContracts);
    private encodeFlags;
    quoteDeliveryPrice(dstChain: Chain): Promise<[bigint[], bigint]>;
    transfer(sender: AccountAddress<C>, amount: bigint, destination: ChainAddress, queue: boolean): AsyncGenerator<EvmUnsignedTransaction<N, C>>;
    redeem(attestations: Ntt.Attestation[]): AsyncGenerator<EvmUnsignedTransaction<N, C>, void, unknown>;
    getCurrentOutboundCapacity(): Promise<bigint>;
    getCurrentInboundCapacity(fromChain: Chain): Promise<bigint>;
    getRateLimitDuration(): Promise<bigint>;
    getInboundQueuedTransfer(fromChain: Chain, transceiverMessage: Ntt.Message): Promise<Ntt.InboundQueuedTransfer<C> | null>;
    completeInboundQueuedTransfer(fromChain: Chain, transceiverMessage: Ntt.Message, token: TokenAddress<C>, payer?: AccountAddress<C>): AsyncGenerator<EvmUnsignedTransaction<N, C>, void, unknown>;
    createUnsignedTx(txReq: TransactionRequest, description: string, parallelizable?: boolean): EvmUnsignedTransaction<N, C>;
}
export {};
//# sourceMappingURL=ntt.d.ts.map